==> libexplain_0.19.D001.orig.tar.gz: libexplain-0.19.D001/libexplain/iocontrol/fdgetprm.c <==
/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2009 Peter Miller
 * Written by Peter Miller <pmiller@opensource.org.au>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/linux/fd.h>

#include <libexplain/iocontrol/fdgetprm.h>


#ifdef FDGETPRM

const explain_iocontrol_t explain_iocontrol_fdgetprm =
{
    "FDGETPRM", /* name */
    FDGETPRM, /* value */
    explain_iocontrol_disambiguate_true, /* synonym FDGETMEDIAPRM */
    0, /* print_name */
    0, /* print_data */
    0, /* print_explanation */
    0, /* print_data_returned */
    __FILE__,
    __LINE__,
};

#else /* ndef FDGETPRM */

const explain_iocontrol_t explain_iocontrol_fdgetprm =
{
    0, /* name */
    0, /* value */
    0, /* disambiguate */
    0, /* print_name */
    0, /* print_data */
    0, /* print_explanation */
    0, /* print_data_returned */
    __FILE__,
    __LINE__,
};

#endif /* FDGETPRM */

==> libexplain_0.31.D001.orig.tar.gz: libexplain-0.31.D001/libexplain/iocontrol/fdgetprm.c <==
/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2009 Peter Miller
 * Written by Peter Miller <pmiller@opensource.org.au>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/linux/fd.h>

#include <libexplain/buffer/floppy_struct.h>
#include <libexplain/iocontrol/fdgetprm.h>
#include <libexplain/iocontrol/generic.h>


#ifdef FDGETPRM

static void
print_data_returned(const explain_iocontrol_t *p,
    struct explain_string_buffer_t *sb, int errnum, int fildes, int request,
    const void *data)
{
    (void)p;
    (void)errnum;
    (void)fildes;
    (void)request;
    explain_buffer_floppy_struct(sb, data);
}


const explain_iocontrol_t explain_iocontrol_fdgetprm =
{
    "FDGETPRM", /* name */
    FDGETPRM, /* value */
    explain_iocontrol_disambiguate_true, /* synonym FDGETMEDIAPRM */
    0, /* print_name */
    explain_iocontrol_generic_print_data_pointer, /* print_data */
    0, /* print_explanation */
    print_data_returned,
    sizeof(struct floppy_struct), /* data_size */
    __FILE__,
    __LINE__,
};

#else /* ndef FDGETPRM */

const explain_iocontrol_t explain_iocontrol_fdgetprm =
{
    0, /* name */
    0, /* value */
    0, /* disambiguate */
    0, /* print_name */
    0, /* print_data */
    0, /* print_explanation */
    0, /* print_data_returned */
    0, /* data_size */
    __FILE__,
    __LINE__,
};

#endif /* FDGETPRM */
